# -*- coding: utf-8 -*-
# 测试用例
# 作者: 陈磊
# 时间: 2019-11-12


from __future__ import division

from WorkCase import CaseBase
from WorkUtils.UtilsLog import UtilsLog
from WorkUtils.UtilsDataBase import UtilsDataBase
from WorkUtils.UtilsResponse import UtilsResponse
from WorkApi.API.HostInterface.hostInterface_create import HostInterfaceCreate
from WorkApi.API.HostInterface.hostInterface_delete import HostInterfaceDelete

from WorkData.Zabbix.interface import DataInterface

import allure

# allure.label("")


@allure.feature("测试模块：hostinterface.delete")
class TestHostInterfaceDelete(object):
    log = UtilsLog()
    env = CaseBase().environment
    host = env["host"]
    db_url = env["db_url"]
    db_port = env["db_port"]
    db_user = env["db_user"]
    db_pw = env["db_pw"]
    db_base = env["db_base"]
    base_name = "SS测试主机接口"
    base_ip = "10.0.0.28"
    base_hostid = 10266
    base_dns = "sanshi.zmops.cn"
    base_port = "127"

    new_ip = "192.168.1.28"
    new_port = "721"

    @classmethod
    def setup_class(cls):
        cls.log.debug("开始执行测试套件.......")
        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataInterface().delete_hostid(session=session, hostid=cls.base_hostid)

    @classmethod
    def teardown_class(cls):
        cls.log.debug("结束执行测试套件.......")

    def setup_method(self):
        self.log.debug("测试用例执行开始...")

    def teardown_method(self):
        self.log.debug("测试用例执行结束...")

    @allure.step("调用接口：hostinterface.create")
    def hostinterface_create(self, dns=None, hostid=None, ip=None, main=None, port=None, _type=None, useip=None, bulk=None):
        api = HostInterfaceCreate(_host=self.host)
        api.dns = dns
        api.hostid = hostid
        api.ip = ip
        api.main = main
        api.port = port
        api.type = _type
        api.useip = useip
        api.bulk = bulk
        api.get_response()
        return api.response

    @allure.step("调用接口：hostinterface.delete")
    def hostinterface_delete(self, interfaceids=None):
        api = HostInterfaceDelete(_host=self.host)
        api.interfaceids = interfaceids
        api.get_response()
        return api.response

    @allure.step("连接数据库：zabbix")
    def db_session(self):
        session = UtilsDataBase().conn_mysql(db_url=self.db_url, db_port=self.db_port, db_base=self.db_base, db_user=self.db_user, db_pw=self.db_pw)
        return session

    @allure.step("创建测试数据")
    def case_create(self, ip, hostid, main, port, _type, useip, bulk, dns):
        response = self.hostinterface_create(ip=ip, hostid=hostid, main=main, port=port, _type=_type, useip=useip, bulk=bulk, dns=dns)
        self.check_code(response=response, code=0)
        interfaceid = UtilsResponse().get_result(response=response)["interfaceids"][0]
        return interfaceid

    @allure.step("查询表：interface")
    def select_interface(self, interfaceid=None):
        session = self.db_session()
        sql = DataInterface().select_all_from_allKeys(session=session, interfaceid=interfaceid)
        return sql

    @allure.step("校验查询结果")
    def check_select(self, interfaceid):
        sql = self.select_interface(interfaceid=interfaceid)
        assert sql == []

    @allure.step("断言返回结果：校验排序")
    def check_sortfield(self, response, possible):
        result = UtilsResponse().get_result(response=response)
        UtilsResponse().check_sort(_list=result, key="groupid", possible=possible)

    @allure.step("断言返回结果：校验返回数据的数量")
    def check_num(self, response, num):
        result = UtilsResponse().get_result(response=response)
        assert len(result) == num

    @allure.step("断言返回结果")
    def check_code(self, response, code):
        _code = UtilsResponse().get_code(response=response)
        assert _code == code

    @allure.step("断言返回错误信息")
    def check_msg(self, response, msg):
        _msg = UtilsResponse().get_msg(response=response)
        assert _msg == msg

    @allure.step("断言返回错误结果")
    def check_status(self, response, status):
        _status = UtilsResponse().get_status(response=response)
        assert _status == status

    @allure.title("hostinterface.delete：删除的ID存在")
    @allure.story("删除主机接口：删除的ID存在")
    @allure.severity("blocker")
    def test_case_01(self):
        interfaceid = self.case_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=1, useip=1, bulk=1)

        response = self.hostinterface_delete(interfaceids=[interfaceid])
        self.check_code(response=response, code=0)
        self.check_select(interfaceid=interfaceid)

    @allure.title("hostinterface.delete：删除的ID不存在 500")
    @allure.story("删除主机接口：删除的ID不存在 500")
    def test_case_02(self):
        interfaceid = self.case_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=2, useip=1, bulk=1)

        response = self.hostinterface_delete(interfaceids=[interfaceid])
        self.check_code(response=response, code=0)
        self.check_select(interfaceid=interfaceid)

        response = self.hostinterface_delete(interfaceids=[interfaceid])
        self.check_status(response=response, status=500)

    @allure.title("hostinterface.delete：删除多个ID")
    @allure.story("删除主机接口：删除多个ID")
    def test_case_03(self):
        interfaceid_1 = self.case_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=2, useip=1, bulk=1)
        interfaceid_2 = self.case_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=0, port=self.base_port, _type=2, useip=1, bulk=1)
        interfaceid_3 = self.case_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=0, port=self.base_port, _type=2, useip=1, bulk=1)

        response = self.hostinterface_delete(interfaceids=[interfaceid_1, interfaceid_2, interfaceid_3])
        self.check_code(response=response, code=0)
        self.check_select(interfaceid=interfaceid_1)
        self.check_select(interfaceid=interfaceid_2)
        self.check_select(interfaceid=interfaceid_3)


if __name__ == "__main__":
    from WorkUtils.UtilsPyTest import UtilsPyTest
    from WorkUtils.UtilsCmd import UtilsCmd

    import os

    # 执行自动化测试用例
    case_info = os.path.split(__file__)
    case = UtilsCmd().pytest_cmd()
    r = UtilsPyTest(case=case, case_info=case_info)
    r.run_main()

    # a = TestHostInterfaceDelete()
    # a.setup_class()
    # a.test_case_03()
    # a.test_case_02()
    # a.test_case_03()
    # a.test_case_06()
